
See the full documentation at https://pyqtcmd.readthedocs.io/en/latest/

Changelog:

1.0.2
=====

  * Make associated buttons visible (or not) when the action
    visibility changes

1.0.1
=====

  * Added a `tip` argument to UICommand, which sets both the tooltip
    and the status tip
